<template>
  <div class="p-4 container mb-5 pb-5 ">
    <!-- هدر -->
    <div class="d-flex justify-content-between align-items-center mb-4">
      <h5 class="fw-bold text-dark mb-0">{{ t('account.business.show.title') }}</h5>
      <nuxt-link to="/account/business" class="btn btn-outline-secondary btn-sm">
        {{ t('account.business.show.back_to_list') }}
        <i class="icon icon-regular-arrow-left"></i>
      </nuxt-link>
    </div>

    <!-- کارت اطلاعات بیزینس -->
    <div class="card border-0 shadow-sm mb-4">
      <div class="card-body p-4">
        <div class="row align-items-center">
          <!-- لوگو و عنوان -->
          <div class="col-md-3 text-center d-flex align-items-center justify-content-start">
            <div class="business-logo-container mb-3 mx-3">
              <img
                  :src="data.business.image || '/logo.png'"
                  alt="لوگو کسب‌وکار"
                  class="img-fluid rounded-circle border border-3 border-white shadow"
              />
            </div>
            <div class="d-flex align-items-start justify-content-end flex-column mx-3">
              <h5 class="fw-bold mb-1">{{ data.business.title }}</h5>
              <span class="badge bg-warning text-dark mb-2">
                {{ data.business.business_type?.title }}
              </span>
              <div class="badge bg-secondary-subtle text-dark mb-3">
                {{ data.business.status?.title }}
              </div>
            </div>
          </div>

          <!-- اطلاعات اصلی -->
          <div class="col-md-6">
            <div class="business-info">
              <div class="info-item mb-3">
                <i class="icon icon-regular-location-crosshairs text-default fs-5"></i>
                <div>
                  <h6 class="text-muted mb-1">{{ t('account.business.show.address') }}</h6>
                  <p class="mb-0">{{ data.business.address || t('account.business.show.no_address') }}</p>
                </div>
              </div>

              <div class="info-item mb-3">
                <i class="icon icon-regular-phone text-default fs-5"></i>
                <div>
                  <h6 class="text-muted mb-1">{{ t('account.business.show.phone') }}</h6>
                  <p class="mb-0">{{ data.business.tel }}</p>
                </div>
              </div>


            </div>
          </div>

          <!-- وضعیت و عملیات -->
          <div class="col-md-3">
            <div class=" text-center">
              <div class="row row-cols-2">
                <div class="col my-2">
                  <nuxt-link :to="'/business/' + data.business.id" class="d-block w-100 btn font-size-12 p-1 btn-success">
                    <i class="icon icon-regular-eye ms-1 text-white"></i> نمایش
                  </nuxt-link>
                </div>
                <div class="col my-2" v-if="data.business.role !== 'user'">
                  <nuxt-link :to="`/account/business/edit/${data.business.id}`" class="d-block w-100 btn font-size-12 p-1 btn-default">
                    <i class="icon icon-regular-pen ms-1"></i>
                    {{ t('account.business.show.edit') }}
                  </nuxt-link>
                </div>

                <div class="col my-2" v-if="data.business.role !== 'user'">
                  <nuxt-link :to="`/account/business/stats/${data.business.id}`" class="d-block w-100 btn font-size-14 p-1 btn-primary">
                    <i class="icon icon-regular-chart-bar-alt ms-1 text-white"></i>
                    {{ t('account.business.show.stats') }}
                  </nuxt-link>
                </div>

                <div class="col my-2" v-if="data.business.role !== 'user'">
                  <nuxt-link :to="`/account/business/users/${data.business.id}`" class="d-block w-100 btn font-size-14 p-1 btn-success">
                    <i class="icon icon-regular-users ms-1 text-white"></i>
                    {{ t('account.business.show.users') }}
                  </nuxt-link>
                </div>

                <div class="col my-2" v-if="data.business.role !== 'user'">
                  <nuxt-link :to="`/account/business/upgrade/${data.business.id}`" class="d-block w-100 btn font-size-14 p-1 btn-warning">
                    <i class="icon icon-regular-star ms-1"></i>
                    {{ t('account.business.show.upgrade') }}
                  </nuxt-link>
                </div>

                <div class="col my-2" v-if="data.business.role !== 'user' && data.business.role !== 'admin'">
                  <button class=" btn btn-danger d-block w-100 font-size-14 p-1" @click="removeItem">
                    <i class="icon icon-regular-trash ms-1 text-white"></i>
                    {{ t('account.business.show.delete') }}
                  </button>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>

    <!-- توضیحات -->
    <div class="card border-0 shadow-sm mb-4">
      <div class="card-body">
        <h5 class="card-title fw-bold mb-3">
          <i class="icon icon-regular-info-circle text-default me-2"></i>
          {{ t('account.business.show.description') }}
        </h5>
        <div v-html="data.business.content"></div>
      </div>
    </div>

    <div>
      <div class="d-flex align-items-center justify-content-between mb-4">
        <h5 class="text-dark fw-bold">{{ t('account.business.show.ads_title') }}</h5>
      </div>

      <div class="row">
        <div v-for="(advertise,index) in data.business.advertises" :key="index" class="col-md-6 col-lg-4 mb-4">
          <advertise-item :data="advertise"/>
        </div>
      </div>
    </div>
  </div>
</template>

<script setup>
import {useI18n} from 'vue-i18n';

const {t} = useI18n();
import 'sweetalert2/dist/sweetalert2.min.css'
import {useRoute, useRouter} from "vue-router";
import {onMounted, reactive} from "vue";
import {useCookie} from "nuxt/app";

// Variable
const route = useRoute();
const router = useRouter();
const token = useCookie('token');
const {$api, $sweetalert} = useNuxtApp();

// Data
const data = reactive({
  business: {},
});

const id = route.params.id;

// Actions
const getBusiness = async () => {
  await $api.post('/user/business/show', {id}).then((value) => {
    data.business = value.data.data;
  })
};

const removeItem = async () => {
  await $sweetalert.confirm(async () => {
    await $api.post('/user/business/delete', {
      id: data.business.id
    }).then((value) => {
      if (value.data.status) {
        $sweetalert.success(t('account.business.show.messages.success'));
        router.push('/account/business');
      } else {
        $sweetalert.error(t('account.business.show.messages.failed'));
      }
    })
  });
};

onMounted(() => {
  getBusiness();
});
</script>

<style scoped>

.business-logo-container {
  width: 150px;
  height: 150px;
  border-radius: 50%;
  padding: 8px;
  background: linear-gradient(135deg, #f8f9fa, #e9ecef);
  box-shadow: inset 0 0 10px rgba(0, 0, 0, 0.05);
}

.business-logo-container img {
  width: 100%;
  height: 100%;
  object-fit: cover;
  border-radius: 50%;
}

.business-info .info-item {
  display: flex;
  gap: 15px;
  align-items: flex-start;
}

.status-badge {
  display: inline-flex;
  align-items: center;
  gap: 5px;
  padding: 8px 15px;
  border-radius: 50px;
  font-size: 0.9rem;
}

@media (max-width: 767.98px) {
  .business-logo-container {
    width: 100px;
    height: 100px;
  }

  .business-info .info-item {
    flex-direction: column;
    gap: 5px;
  }

  .status-section {
    margin-top: 20px;
  }
}
</style>